# wiki_as_base-py
[early-draft] Use MediaWiki Wiki page content as read-only database. Python library implementation. See https://github.com/fititnt/openstreetmap-serverless-functions/tree/main/function/wiki-as-base


## Installing

```bash
pip install wiki_as_base --upgrade
```

## License

Public domain
